import datetime as dt
from dateutil.relativedelta import relativedelta

def table_exists(spark, table_name):
    return spark._jsparkSession.catalog().tableExists(table_name)

def get_latest_date(spark, table_name, date_column, default_date=None):
    if table_exists(spark, table_name) == False:
        return default_date
    query = f'SELECT max({date_column}) as latest_date FROM {table_name}'
    latest_date = spark.sql(query).first()['latest_date']
    return latest_date

def get_months_interval(start_date_str, months, date_fmt='%Y-%m-%d'):
    latest_datetime = dt.datetime.strptime(start_date_str, date_fmt)
    return (latest_datetime + relativedelta(months=months)).strftime(date_fmt)

def get_days_interval(start_date_str, days, date_fmt='%Y-%m-%d'):
    latest_datetime = dt.datetime.strptime(start_date_str, date_fmt)
    return (latest_datetime + relativedelta(days=days)).strftime(date_fmt)

def get_interval_query(table_name, date_column, latest_date, end_date):
    return f"SELECT * FROM {table_name} WHERE {date_column} > '{latest_date}' and {date_column} <= '{end_date}'"

def create_or_append_to_hive_table(spark, table_name, partition_column, df):
    if table_exists(spark, table_name):
        print("Appending to existing table: ", table_name)
        df.write.mode("append").partitionBy(partition_column).saveAsTable(table_name)
    else:
        print("Creating table:", table_name)
        df.write.partitionBy(partition_column).saveAsTable(table_name)
