import os, glob
try:
	from pyspark.sql import SparkSession
except:
	pass

def sparkSession(master='local', appName='sparkApp', host='ai-center.se', port=9083):

        hive_lib_dir = "/opt/hops_conf/apache-hive-1.2.1-bin/lib/"

        jar_paths = [x for x in  glob.glob(hive_lib_dir + '/*.jar')]

        jar_paths.append("/opt/hops_conf/hsfs-2.0.2.jar")
        jar_paths.append("/opt/hops_conf/hopsfs-client-2.8.0.1.jar")
        jar_paths.append("/opt/hops_conf/hopsfs-client-api-2.8.2.10-EE-RC0.jar")

        spark = (SparkSession.builder.master(master)
                .appName(appName)
                .config("spark.hadoop.hops.ipc.server.ssl.enabled", "true")
                .config("spark.hadoop.fs.hopsfs.impl", "io.hops.hopsfs.client.HopsFileSystem")
                .config("spark.hadoop.client.rpc.ssl.enabled.protocol", "TLSv1.2")
                .config("spark.hadoop.hops.ssl.keystore.name", "/opt/hops_conf/keyStore.jks")
                .config("spark.hadoop.hops.rpc.socket.factory.class.default", "io.hops.hadoop.shaded.org.apache.hadoop.net.HopsSSLSocketFactory")
                .config("spark.hadoop.hops.ssl.keystores.passwd.name", "/opt/hops_conf/material_passwd")
                .config("spark.sql.hive.metastore.jars", "/opt/hops_conf/apache-hive-1.2.1-bin/lib/*")
                .config("spark.hadoop.hops.ssl.hostname.verifier", "ALLOW_ALL")
                .config("spark.hadoop.hops.ssl.trustore.name", "/opt/hops_conf/trustStore.jks")
                .config("spark.hadoop.hive.metastore.uris", "thrift://" + host + ":" + str(port))
                .config("spark.hadoop.yarn.timeline-service.enabled", "false")
                .config("spark.jars", ",".join(jar_paths))
                .enableHiveSupport()
                .getOrCreate()
                )

        return spark
